ClipState

Struct ClipState 

pub struct ClipState {
    context: ClipContext,
    context_pool: Pool<ClipContext>,
    path_elements: Vec<PathEl>,
    raw_clips: Vec<RawClip>,
    frames: Vec<ClipFrame>,
    revision: u64,
}
State for managing clip paths across multiple viewports.

Fields

context: ClipContext

The currently active clip context.

context_pool: Pool<ClipContext>

A pool of reusable clip contexts.

path_elements: Vec<PathEl>

A flat factor of path elements storing the original path data of clip paths.

raw_clips: Vec<RawClip>

Raw data of the currently active stack of clip paths

frames: Vec<ClipFrame>

Stack of pushed clip frames.

revision: u64

The current revision.

Implementations

Source

impl ClipState

pub fn new() -> Self

Create a new clip state.

pub fn get(&self) -> Option<PathDataRef<'_>>

Return the current clip path.

pub fn push_root_viewport( &mut self, source_shift: (u16, u16), strip_generator: &mut StripGenerator, )

Push a new root viewport.

pub fn pop_root_viewport(&mut self, strip_generator: &mut StripGenerator)

Pop the last root viewport.

pub fn push_clip( &mut self, path: &BezPath, strip_generator: &mut StripGenerator, fill_rule: Fill, transform: Affine, aliasing_threshold: Option<u8>, )

Push a clip path.

pub fn pop_clip(&mut self)

Pop the active clip path.

pub fn reset(&mut self)

Reset the clip state.

fn active_shift(&self) -> Affine

fn rebuild_context(&mut self, strip_generator: &mut StripGenerator)