pub struct PathDataRef<'a> {
pub strips: &'a [Strip],
pub alphas: &'a [u8],
pub bbox: RectU16,
}Expand description
Borrowed data of a stripped path.
Fields
strips: &'a [Strip]The strips.
alphas: &'a [u8]The alpha buffer.
bbox: RectU16A tile-aligned coarse bounding box of the clip path in pixel coordinates.
These bounds have already been intersected with the viewport.